using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using BarcodeLib.Barcode;
using System.Drawing.Imaging;
using System.IO;
using BarcodeLib.Barcode.Linear;

namespace WinDemo
{
    public partial class PDF417Form : Form
    {
        public PDF417Form()
        {
            InitializeComponent();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            base.Close();
        }

        private void PDF417Form_Load(object sender, EventArgs e)
        {
            ctrMode.SelectedIndex = 1;
            ctrEcl.SelectedIndex = 2;
            ctrCompact.SelectedIndex = 1;
            ctrProcessTilde.SelectedIndex = 0;
            ctrBarRatio.SelectedIndex = 1;
            ctrImageFormat.SelectedIndex = 0;

            ctrUOM.SelectedIndex = 0;

            barcode.Data = "BarcodeLib.com";
            barcode.Refresh();
        }

        private void drawBarcode()
        {
            barcode.Data = ctrData.Text;
            barcode.Mode = BarcodeUtils.convertString2PDF417Mode(ctrMode.Text);
            barcode.ECL = (BarcodeLib.Barcode.PDF417.ErrorCorrectionLevel)int.Parse(ctrEcl.Text);
            barcode.Compact = bool.Parse(ctrCompact.Text);
            barcode.ProcessTilde = bool.Parse(ctrProcessTilde.Text);
            barcode.UOM = (UnitOfMeasure)ctrUOM.SelectedIndex;
            barcode.BarWidth = float.Parse(ctrBarWidth.Text);
            barcode.BarRatio = int.Parse(ctrBarRatio.Text);
            barcode.Rows = int.Parse(ctrRows.Text);
            barcode.Columns = int.Parse(ctrColumns.Text);
            barcode.LeftMargin = float.Parse(ctrLeftMargin.Text);
            barcode.RightMargin = float.Parse(ctrRightMargin.Text);
            barcode.TopMargin = float.Parse(ctrTopMargin.Text);
            barcode.BottomMargin = float.Parse(ctrBottomMargin.Text);

            barcode.Resolution = int.Parse(ctrResolution.Text);

            barcode.ImageFormat = BarcodeUtils.convertString2ImageFormat(ctrImageFormat.Text, ImageFormat.Gif);

            barcode.Refresh();
        }

        private void ctrDrawBarcode_Click(object sender, EventArgs e)
        {
            bool validInputs = verifyInputs();
            if (validInputs)
                drawBarcode();
        }

        private bool verifyInputs()
        {
            string errorMessage = "";
            if (ctrData.Text.Trim().Equals(""))
            {
                errorMessage = "Barcode data cannot be empty.";
                ctrData.Focus();
            }

            try
            {
                float v = float.Parse(ctrBarWidth.Text);
                if (v <= 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for bar width.";
                ctrBarWidth.Focus();
            }

            try
            {
                int v = int.Parse(ctrRows.Text);
                if (!(v == 0 || (v>= 3 && v<=90)))
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "Valid values for rows, 0 (decided by system), and 3 - 90.";
                ctrRows.Focus();
            }

            try
            {
                int v = int.Parse(ctrColumns.Text);
                if (!(v >= 1 && v <= 30))
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "Valid values for columns, 1 - 30.";
                ctrColumns.Focus();
            }

            try
            {
                float v = float.Parse(ctrLeftMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for left margin.";
                ctrLeftMargin.Focus();
            }

            try
            {
                float v = float.Parse(ctrRightMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for right margin.";
                ctrRightMargin.Focus();
            }
            try
            {
                float v = float.Parse(ctrTopMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for top margin.";
                ctrTopMargin.Focus();
            }
            try
            {
                float v = float.Parse(ctrBottomMargin.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "float only for bottom margin.";
                ctrBottomMargin.Focus();
            }

            try
            {
                int v = int.Parse(ctrResolution.Text);
                if (v < 0)
                {
                    throw new FormatException();
                }
            }
            catch (System.FormatException e)
            {
                errorMessage = "int only for resolution.";
                ctrResolution.Focus();
            }

            if (!errorMessage.Equals(""))
            {
                MessageBox.Show(errorMessage);
                return false;
            }

            return true;
        }

        private void ctrSaveImage_Click(object sender, EventArgs e)
        {
            bool validInputs = verifyInputs();
            if (!validInputs)
                return;

            saveFileDialog.Filter = "GIF (*.gif)|*.gif|JPEG (*.jpg)|*.jpg|BMP (*.bmp)|*.bmp";
            saveFileDialog.FilterIndex = 1;

            if (saveFileDialog.ShowDialog() == DialogResult.OK)
            {
                drawBarcode();

                Stream imageStream = null;
                if ((imageStream = saveFileDialog.OpenFile()) != null)
                {
                    barcode.SaveAsImage(imageStream);
                    if (imageStream != null)
                        imageStream.Close();
                }
            }
        }


        
    }
}